@@ -7,6 +7,8 @@
 #include <S.h>
 #include <Mathlib.h>
 
+#include "ctest.h"
+
 static double **w;
 
 static void
@@ -15,7 +17,7 @@ errmsg(char *s) {
 }
 
 void
-kendall_tau(int *n, double *x, double *y, double *tau) {
+kendall_tau(Sint *n, double *x, double *y, double *tau) {
     double c = 0, vx = 0, vy = 0, sx, sy;
     int i, j;
 
@@ -61,8 +63,8 @@ ckendall(int k, int n) {
 }
 
 void
-dkendall(int *len, double *x, int *n) {
-    int i;
+dkendall(Sint *len, double *x, Sint *n) {
+    Sint i;
 
     w = Calloc(*n, double *);
     if (!w)
@@ -77,8 +79,8 @@ dkendall(int *len, double *x, int *n) {
 }
 
 void
-pkendall(int *len, double *x, int *n) {
-    int i, j;
+pkendall(Sint *len, double *x, Sint *n) {
+    Sint i, j;
     double p, q;
 
     w = Calloc(*n, double *);
